@@ -1,6 +1,6 @@
 package TPath;
 {
-  $TPath::VERSION = '0.008';
+  $TPath::VERSION = '0.009';
 }
 
 # ABSTRACT: general purpose path languages for trees
@@ -17,7 +17,7 @@ TPath - general purpose path languages for trees
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -163,9 +163,9 @@ A tpath expression has one or more sub-paths.
 
 =over 2
 
-C<B<//a/b>|preceding::d/*>
+=item C<B<//a/b>|preceding::d/*>
 
-C<//a/b|B<preceding::d/*>>
+=item C<//a/b|B<preceding::d/*>>
 
 =back
 
@@ -179,11 +179,11 @@ descendants will be listed first.
 
 =over 2
 
-C<B<//a>/b[0]/E<gt>c[@d]>
+=item C<B<//a>/b[0]/E<gt>c[@d]>
 
-C<//aB</b[0]>/E<gt>c[@d]>
+=item C<//aB</b[0]>/E<gt>c[@d]>
 
-C<//a/b[0]B</E<gt>c[@d]>>
+=item C<//a/b[0]B</E<gt>c[@d]>>
 
 =back
 
@@ -194,13 +194,13 @@ number of predicates.
 
 =over 2
 
-C<a/b/c/E<gt>d>
+=item C<a/b/c/E<gt>d>
 
-C<B</>aB</>b//c/E<gt>d>
+=item C<B</>aB</>b//c/E<gt>d>
 
-C<B<//>a/bB<//>c/E<gt>d>
+=item C<B<//>a/bB<//>c/E<gt>d>
 
-C<B</E<gt>>a/b//cB</E<gt>>d>
+=item C<B</E<gt>>a/b//cB</E<gt>>d>
 
 =back
 
@@ -208,7 +208,7 @@ C<B</E<gt>>a/b//cB</E<gt>>d>
 
 =over 2
 
-C<a/b/c/E<gt>d>
+=item C<a/b/c/E<gt>d>
 
 =back
 
@@ -220,7 +220,7 @@ where C</a> means the file C<a> in the root directory and C<a> means the file C<
 
 =over 2
 
-C<B</>aB</>b//c/E<gt>d>
+=item C<B</>aB</>b//c/E<gt>d>
 
 =back
 
@@ -231,7 +231,7 @@ the first step it means that the context node is the root node.
 
 =over 2
 
-C<B<//>a/bB<//>c/E<gt>d>
+=item C<B<//>a/bB<//>c/E<gt>d>
 
 =back
 
@@ -242,7 +242,7 @@ context node is the root, "search among the root node and its descendants".
 
 =over 2
 
-C<B</E<gt>>a/b//cB</E<gt>>d>
+=item C<B</E<gt>>a/b//cB</E<gt>>d>
 
 =back
 
@@ -272,7 +272,7 @@ Selectors select a candidate set for later filtering by predicates.
 
 =over 2
 
-C<B<a>>
+=item C<B<a>>
 
 =back
 
@@ -287,7 +287,7 @@ backslash. Any unexpected character must be escaped. So
 
 =over 2
 
-C<a\\b>
+=item C<a\\b>
 
 =back
 
@@ -297,7 +297,7 @@ represents the literal C<a\b>.
 
 =over 2
 
-C<~a~>
+=item C<~a~>
 
 =back
 
@@ -317,9 +317,9 @@ the effect of an attribute selector with the null separator, however, in two way
 
 =over 2
 
-C<child::@foo>
+=item C<child::@foo>
 
-C<./@foo>
+=item C<./@foo>
 
 =back
 
@@ -330,13 +330,13 @@ path.
 
 The C<^> character before a literal, regex, or attribute selector will convert it into an attribute selector.
 
-=over2
+=over 2
 
-C<//B<^>foo>
+=item C<//B<^>foo>
 
-C<//B<^>~foo~>
+=item C<//B<^>~foo~>
 
-C<//B<^>@foo>
+=item C<//B<^>@foo>
 
 =back
 
@@ -625,13 +625,13 @@ are selected from the tree relative the the C<c> node. Selected nodes will be in
 
 =over 2
 
-C<//a/bB<[0]>/E<gt>c[@d][@e E<lt> 'string'][@f or @g]>
+=item C<//a/bB<[0]>/E<gt>c[@d][@e E<lt> 'string'][@f or @g]>
 
-C<//a/b[0]/E<gt>B<c[@d]>[@e E<lt> 'string'][@f or @g]>
+=item C<//a/b[0]/E<gt>B<c[@d]>[@e E<lt> 'string'][@f or @g]>
 
-C<//a/b[0]/E<gt>c[@d]B<[@e E<lt> 'string']>[@f or @g]>
+=item C<//a/b[0]/E<gt>c[@d]B<[@e E<lt> 'string']>[@f or @g]>
 
-C<//a/b[0]/E<gt>c[@d][@e E<lt> 'string']B<[@f or @g]>>
+=item C<//a/b[0]/E<gt>c[@d][@e E<lt> 'string']B<[@f or @g]>>
 
 =back
 
@@ -733,7 +733,8 @@ interpreted as part of a path or attribute.
 
 =head2 Special Selectors
 
-There are three special selectors B<that cannot occur with predicates>.
+There are three special selectors B<that cannot occur with predicates> and may only be 
+preceded by the C</> or null separators.
 
 =head3 . : Select Self
 
@@ -743,11 +744,16 @@ This is an abbreviation for C<self::*>.
 
 This is an abbreviation for C<parent::*>.
 
-=head3 id(foo) : Select By Index
+=head3 :id(foo) : Select By Index
 
 This selector selects the node, if any, with the given id. This same node can also be selected
 by C<//*[@id = 'foo']> but this is much less efficient.
 
+=head3 :root : Select Root
+
+This expression selects the root of the tree. It doesn't make much sense except as the
+first step in an expression.
+
 =head2 Hiding Nodes
 
 In some cases there may be nodes -- spaces, comments, hidden directories and files -- that you
