@@ -1,6 +1,6 @@
 package TPath::Selector::Test::AnywhereTag;
 {
-  $TPath::Selector::Test::AnywhereTag::VERSION = '0.008';
+  $TPath::Selector::Test::AnywhereTag::VERSION = '0.009';
 }
 
 # ABSTRACT: handles C<//foo> expression
@@ -12,16 +12,21 @@ use namespace::autoclean;
 
 with 'TPath::Selector::Test';
 
-has first => ( is => 'ro', isa => 'Bool', required => 1 );
-
 has tag => ( is => 'ro', isa => 'Str', required => 1 );
 
+around BUILDARGS => sub {
+	my ( $orig, $class, %args ) = @_;
+	$class->$orig(
+		%args,
+		first_sensitive => 1,
+		axis            => 'descendant',
+	);
+};
+
 sub BUILD {
-    my $self = shift;
-    my $nt = TPath::Test::Node::Tag->new( tag => $self->tag );
-    $self->_node_test($nt);
-    my $axis = $self->first ? 'descendant-or-self' : 'descendant';
-    $self->_axis($axis);
+	my $self = shift;
+	my $nt = TPath::Test::Node::Tag->new( tag => $self->tag );
+	$self->_node_test($nt);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -38,7 +43,7 @@ TPath::Selector::Test::AnywhereTag - handles C<//foo> expression
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 ROLES
 
