@@ -7,7 +7,7 @@ use TPath::Grammar qw(parse);
 use Data::Dumper;
 use Perl::Tidy;
 
-my $parse = parse(q{id(foo)/following::*|.|/.|./child::^a});
+my $parse = parse(q{a(/b|/c)|a?});
 my $code  = Dumper $parse;
 my $ds;
 Perl::Tidy::perltidy( source => \$code, destination => \$ds );
